//+------------------------------------------------------------------+
//|                              London Breakout Input Caculator.mq4 |
//+------------------------------------------------------------------+

/*+------------------------------------------------------------------+
 *
 * Helper script designed for use with the "London Breakout.mq4" indicator;
 *
 * Use this script to compute the Indicator inputs from your required MaxEntryDistance/MaxTP/MaxSL amounts.
 * The script will also SET the corresponding GlobalVariables that the Indicator would typically generate
 * based on the Indicator inputs, so that you can use "London Breakout scriptV3" script directly,
 * to immediately use these new calculated settings for opening orders.
 *
 * All inputs are in pips.
 *
 * Because the box is of variable size by nature, this script considers that you want a MAXIMUM
 * box size of "MaxEntryDistance" pips, and will give you the value to be set in the "MaxExtentInPips" indicator input.
 * You can then decide to set it or not in the indicator.
 * You can eventually also set the "MinExtentInPips" indicator input to limit the trade minimum levels.
 * 
 * Inputs:
 * "MaxEntryDistance": max distance of buy/sell Entry prices from the MEDIAN PRICE of the Indicator box;
 * "MaxTP" and "MaxSL": expected MaxTP and MaxSL pips;
 *
 * Outputs:
 * "EntryFactor", "TPFactor", "LevelsResizeFactor", "MaxExtentInPips"
 * to be used as inputs for the "London Breakout.mq4" indicator;
 * Note: "LevelsResizeFactor" will always be 1.0, to keep the default original Indicator value;
 *
 *+------------------------------------------------------------------+
 * Version history:
 *
 * V1: Initial version from Squalou
 * 
 *+------------------------------------------------------------------+
 */


#property copyright "Copyright  2009, Steve Hopwood"
#property link      "http://www.hopwood3.freeserve.co.uk"
#include <WinUser32.mqh>
#include <stdlib.mqh>
#property show_inputs


extern int     MagicNumber=274693;
extern string  Info = "London breakout calculator script";
extern string  objPrefix = "LB-";  // Prefix of London Breakout Indicator objects;
extern string  Usage = "0 values will default to current chart LB values";
extern double  MaxEntryDistance = 20;
extern double  MaxTP = 60;
extern double  MaxSL = 30;


//+------------------------------------------------------------------+
//| script program start function                                    |
//+------------------------------------------------------------------+
int start()
{
  double MaxExtentInPips,EntryFactor,TPFactor,SLFactor;

  MaxExtentInPips = 2*(MaxSL-MaxEntryDistance);
  EntryFactor     = MaxSL / MaxExtentInPips - 1;
  TPFactor        = (MaxTP+MaxSL) / MaxExtentInPips - 1;


  GlobalVariableSet(objPrefix+Symbol()+"-EntryFactor", EntryFactor);
  GlobalVariableSet(objPrefix+Symbol()+"-TPFactor", TPFactor);
  GlobalVariableSet(objPrefix+Symbol()+"-LevelsResizeFactor", 1.0);
  GlobalVariableSet(objPrefix+Symbol()+"-MaxExtentInPips", MaxExtentInPips);

  Alert (objPrefix+Symbol()+" MaxExtentInPips = "+DoubleToStr(MaxExtentInPips,1));
  Alert (objPrefix+Symbol()+" LevelsResizeFactor = 1.0");
  Alert (objPrefix+Symbol()+" TPFactor = "+DoubleToStr(TPFactor,1));
  Alert (objPrefix+Symbol()+" EntryFactor = "+DoubleToStr(EntryFactor,1));


  return(0);
}
//+------------------------------------------------------------------+