//+------------------------------------------------------------------+
//|                                       London Breakout script.mq4 |
//|                                  Copyright  2009, Steve Hopwood |
//|                              http://www.hopwood3.freeserve.co.uk |
//+------------------------------------------------------------------+

/*+------------------------------------------------------------------+
 *
 * Version history:
 *
 * V3: [Squalou]
 *     - added "CloseHalfTradeAtHalfTP"(false) input:
 *       when true, will place orders of half lots each, so that 
 *       half of the orders have full TP and half have half TP targets;
 *     - added more explicit alert/print information;
 *
 * V2: [Squalou]
 *     - Buy/Sell Entry/TP/SL prices left to 0 are "imported" from 
 *       GlobalVariables set by the "London BreakoutV7.mq4" (or higher) indicator;
 *     
 * This is an improvement of Steve Hopwoods script posted on
 * http://www.forexfactory.com/showthread.php?t=230640
 *
 * It is designed to work with the "London BreakoutV7.mq4" indicator
 * or any higher version of it.
 *
 * You must have loaded the "London BreakoutV7.mq4" indicator (or higher version) on the chart,
 * so that this script can retrieve the corresponding entry/TP/SL levels
 * for the BuyStop and SellStop orders that it will place.
 *
 * Values in this script's inputs left to 0 will automatically be set
 * to the Indicators calculated values, so you don't need to manually input them.
 *
 * (V1): original version, courtesy of Steve Hopwood;
 *
 *+------------------------------------------------------------------+
 */


#property copyright "Copyright  2009, Steve Hopwood"
#property link      "http://www.hopwood3.freeserve.co.uk"
#include <WinUser32.mqh>
#include <stdlib.mqh>
#property show_inputs


extern double  Lot=0.02;
extern int     MagicNumber=274693;
extern string  TradeComment="London breakout script";
extern string  objPrefix = "LB-LD-";  // Prefix of London Breakout Indicator objects;
extern string  Usage = "0 values will default to current chart LB values";
extern double  LongPendingEntryPrice;
extern double  LongTP;
extern double  LongSL;
extern double  ShortPendingEntryPrice;
extern double  ShortTP;
extern double  ShortSL;
extern bool    CloseHalfTradeAtHalfTP = false;

void init()
{

  // replace default 0 inputs with London Breakout Indicator global variables set on the current chart
  if (LongPendingEntryPrice==0) LongPendingEntryPrice = GlobalVariableGet(objPrefix+Symbol()+"-LongEntry");
  if (ShortPendingEntryPrice==0) ShortPendingEntryPrice = GlobalVariableGet(objPrefix+Symbol()+"-ShortEntry");
  if (LongTP==0) LongTP = GlobalVariableGet(objPrefix+Symbol()+"-LongTP");
  if (ShortTP==0) ShortTP = GlobalVariableGet(objPrefix+Symbol()+"-ShortTP");
  if (LongSL==0) LongSL = GlobalVariableGet(objPrefix+Symbol()+"-LongSL");
  if (ShortSL==0) ShortSL = GlobalVariableGet(objPrefix+Symbol()+"-ShortSL");

}



//+------------------------------------------------------------------+
//| script program start function                                    |
//+------------------------------------------------------------------+
int start()
{
//----
   
   int ticket;

   Alert("--- START "+WindowExpertName()+" "+Symbol());
      
   //Long trade
   if (!CloseHalfTradeAtHalfTP) {
      place_order(OP_BUYSTOP,"Pending long", Lot, LongPendingEntryPrice, LongSL,  LongTP, MagicNumber);
   } else {
      place_order(OP_BUYSTOP,"Pending long", Lot/2, LongPendingEntryPrice, LongSL,  LongTP, MagicNumber);
      place_order(OP_BUYSTOP,"Pending long", Lot/2, LongPendingEntryPrice, LongSL, (LongTP+LongPendingEntryPrice)/2, MagicNumber+1);
   }

   //Short trade
   if (!CloseHalfTradeAtHalfTP) {
      place_order(OP_SELLSTOP, "Pending short",Lot, ShortPendingEntryPrice, ShortSL, ShortTP, MagicNumber);
   } else {
      place_order(OP_SELLSTOP, "Pending short",Lot/2, ShortPendingEntryPrice, ShortSL, ShortTP, MagicNumber);
      place_order(OP_SELLSTOP, "Pending short",Lot/2, ShortPendingEntryPrice, ShortSL, (ShortTP+ShortPendingEntryPrice)/2, MagicNumber+1);
   }

  Alert("--- END "+WindowExpertName()+" "+Symbol());

//----
   return(0);
}
   

//+------------------------------------------------------------------+
bool DoesTradeExist(int type, double MagicNumber)
//+------------------------------------------------------------------+
{
   //Searches for open trades
   
   if (OrdersTotal() == 0) return(false); //nothing to do

   for (int cc = OrdersTotal() - 1; cc >= 0; cc--)
   {      
      if (!OrderSelect(cc, SELECT_BY_POS) ) continue;
      if (OrderMagicNumber() == MagicNumber && OrderSymbol() == Symbol() && OrderType() == type) 
      {        
         return(true);         
      }//if (OrderMagicNumber() == MagicNumber && OrderSymbol() == Symbol() && OrderType() == type) 
   }//for (int cc = OrdersTotal() - 1; cc >= 0, cc--)  
   
   return(false);
   
}// DoesTradeExist()

//+------------------------------------------------------------------+
void place_order(int type, string stype, double Lot, double PendingEntryPrice, double SL, double TP, double MagicNumber)
//+------------------------------------------------------------------+
{
   int ticket,err;

   if (!DoesTradeExist(type, MagicNumber))
   {
      while (!IsTradeAllowed()) Sleep(500); // wait for Trade to be allowed(free context)

      ticket = OrderSend(Symbol(), type, Lot, PendingEntryPrice, 0, SL, TP, TradeComment, MagicNumber, 0,Green);
      if (ticket < 0)
      {
         err=GetLastError();
         Alert(Symbol()+":"+stype+" FAILED ("+err+"): "+ErrorDescription(err));
         return;
      } else {
         Alert(Symbol()+":"+stype+" at "+DoubleToStr(PendingEntryPrice,Digits)+" TP="+DoubleToStr(TP,Digits)+",SL="+DoubleToStr(SL,Digits));
      }
   }

}
//+------------------------------------------------------------------+


